/************************************************************************/
/*		aISA-A35 Device Driver for Windows 95/NT						*/
/*																		*/
/*			aisa35.h	-	Win32 interface definition					*/
/*			date		-	1998/09/01									*/
/************************************************************************/

#if !defined( AISA35_H )
#define	AISA35_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	AISA35_SUCCESS					0	/* Successfully proccessed */
#define	AISA35_ERR_SYSTEM				1	/* Call GetLastError() */
#define	AISA35_ERR_NO_DEVICE			2	/* No card */
#define	AISA35_ERR_IN_USE				3	/* Device is in use */
#define	AISA35_ERR_INVALID_SLOT			4	/* Invalid slot number */
#define	AISA35_ERR_RESOURCE				5	/* Resource exhaustion */
#define	AISA35_ERR_INVALID_ARGUMENT		6	/* Invalid argument */
#define	AISA35_ERR_NO_CREATE			7	/* No created device */
#define AISA35_ERR_INVALID_CHANNEL		8	/* Invalid channel */
#define	AISA35_ERR_INVALID_RESOLUTION	9	/* Invalid resolution */
#define	AISA35_ERR_TIMEOUT				10	/* Conversion timeout */

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	AISA35_MAX_SLOTS	16			/* Maximum number of slots */

										/* default search */
#define	AISA35_SLOT_AUTO	( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	AISA35_BOARD_ID		0x0035		/* isa bus device id */
#define	AISA35_VENDOR_ID	0x0000		/* isa bus vendor id */
										/* our device id */
#define	AISA35_DEVICE_ID	( ( DWORD )AISA35_BOARD_ID\
							| ( ( DWORD )AISA35_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	AISA35_MAX_MEM		9			/* number of memory windows */
#define	AISA35_MAX_IO		20			/* number of i/o windows */
#define	AISA35_MAX_IRQ		7			/* number of irqs */
#define	AISA35_MAX_DMA		7			/* number of dmas */

typedef	struct	_AISA35RESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[AISA35_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[AISA35_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[AISA35_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[AISA35_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[AISA35_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Not used */
	DWORD	dwIRQRegisters	[AISA35_MAX_IRQ];	/* Not used */
	DWORD	dwIRQAttrib		[AISA35_MAX_IRQ];	/* Not used */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[AISA35_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[AISA35_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} AISA35RESOURCE, *PAISA35R;

/*==================================*/
/*	Sampling parameter structure	*/
/*==================================*/
typedef struct _AISA35PARA {
	DWORD	dwSamplingChannel;					/* Sampling channel */
	DWORD	dwResolution;						/* Resolution 8bits/12bits */
} AISA35PARA, *PAISA35P;

#if !defined( AISA35_DRIVER )
#define	AISA35_API

#if !defined( AISA35_DLL )
	#define AISA35LIB_API	extern __declspec( dllimport )
#else
	#define AISA35LIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

AISA35LIB_API BOOL	WINAPI	Aisa35GetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
AISA35LIB_API BOOL	WINAPI	Aisa35Create( PWORD pwLogSlot );
AISA35LIB_API BOOL	WINAPI	Aisa35Close( WORD wLogSlot );
AISA35LIB_API BOOL	WINAPI	Aisa35GetResource( WORD wLogSlot, PAISA35R pres );
AISA35LIB_API BOOL	WINAPI	Aisa35StartSampling( WORD wLogSlot, PAISA35P pcpara, PWORD pwSamplingData );
AISA35LIB_API BOOL	WINAPI	Aisa35InPort( WORD wLogSlot, PBYTE pbInValue );
AISA35LIB_API BOOL	WINAPI	Aisa35OutPort( WORD wLogSlot, BYTE bOutValue );
AISA35LIB_API DWORD	WINAPI	Aisa35GetLastError( WORD wLogSlot );

#endif	/* #if !defined( AISA35_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( AISA35_H ) */

/**/